aboutsummaryrefslogtreecommitdiff
path: root/target-m68k/cpu.h
diff options
context:
space:
mode:
Diffstat (limited to 'target-m68k/cpu.h')
-rw-r--r--target-m68k/cpu.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/target-m68k/cpu.h b/target-m68k/cpu.h
index 3a1a13888b..a81b91dffd 100644
--- a/target-m68k/cpu.h
+++ b/target-m68k/cpu.h
@@ -160,7 +160,8 @@ enum m68k_features {
M68K_FEATURE_CF_FPU,
M68K_FEATURE_CF_MAC,
M68K_FEATURE_CF_EMAC,
- M68K_FEATURE_EXT_FULL /* 68020+ full extension word. */
+ M68K_FEATURE_EXT_FULL, /* 68020+ full extension word. */
+ M68K_FEATURE_WORD_INDEX /* word sized address index registers. */
};
static inline int m68k_feature(CPUM68KState *env, int feature)